@@ -22,8 +22,16 @@ class Logger(object):
                  default_level='log', #function with will be used by default. If object of CSVLogger will be called as function
                  loglev=None, #all available function or levels for logging
                  func_fields=None, # function which will be logged in every log
-                 buffering=0
+                 buffering=0,
+                 related_folder = None
                  ):
+        if related_folder:
+            related_folder = os.path.abspath(related_folder)
+            if not related_folder.endswith('/'):
+                related_folder += '/'
+
+        self.related_folder = related_folder
+
 
 
         self.action_log_template = action_log
@@ -204,7 +212,7 @@ class Logger(object):
         if self.aindex_empty_level:
             return [record_key]
         arr_row = [record_key,self.get_append_time()] +\
-                self.arr_funcs(self.func_fields,sys._getframe(stack)) +\
+                self.arr_funcs(self.func_fields,sys._getframe(stack),self) +\
                 self.unpack_params(params)
         self.store_row(arr_row)
         return arr_row
